@@ -227,9 +227,10 @@ class configuration(GObject.GObject):
 
     def append_log(self,data,cr = True):
 
-        self.log+=data
+        self.log += data
         if (cr):
             self.log += "\n"
+            
 
     def append_static_log(self,data,cr = True):
         
@@ -247,4 +248,4 @@ class configuration(GObject.GObject):
 
     def get_log(self):
 
-        return self.static_log + "\n" + self.log
+        return "Static data:\n\n" + self.static_log + "\n\nDynamic data:\n\n" + self.log
